

clear
set more off
set linesize 120
version 15
capture do c:\ado\profile_temp.do
capture cd "$GoogleDriveLaptop"
capture cd "$GoogleDriveWork"
capture cd ".\Talks\AllTalks\15_IntroToBayes\examples"


capture log close
log using IntroToBayes, replace

global Width16x9 = 1920
global Height16x9 = 1080

global Width4x3 = 1440*2
global Height4x3 = 1080*2


set seed 15


// LINEAR REGRESSION
// ============================================================================
use test_1level.dta, clear

describe

regress score age sex

bayes: regress score age sex

bayes: regress score age sex, noheader

bayes, rseed(15): regress score age sex, noheader

bayes, mcmcsize(20000) rseed(15): regress score age sex, noheader

bayes, prior({score:_cons}, uniform(0,100000)): regress score age sex, noheader

bayes, prior({score:}, flat) rseed(15): regress score age sex, noheader




bayesstats ess

bayesgraph diagnostics {score:_cons}
graph export ./graphs/bg_cons.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph diagnostics {score:age}
graph export ./graphs/bg_age.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph diagnostics {score:sex}
graph export ./graphs/bg_sex.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph diagnostics {sigma2}
graph export ./graphs/bg_sigma2.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph trace {score:_cons age sex} {sigma2}, byparm
graph export ./graphs/bg_trace.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph histogram {score:_cons age sex} {sigma2}, byparm
graph export ./graphs/bg_histogram.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph kdensity {score:_cons age sex} {sigma2}, byparm
graph export ./graphs/bg_kdensity.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph ac {score:_cons age sex} {sigma2}, byparm
graph export ./graphs/bg_ac.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph matrix _all
graph export ./graphs/bg_matrix.png, as(png) width($Width16x9) height($Height16x9) replace

bayesstats summary {score:_cons age sex} {sigma2}

bayestest interval {score:sex}, lower(1.5) upper(2.5)

bayesstats summary (predicted: {score:_cons} + {score:age}*16 + {score:sex}*1)



bayesstats summary (pred14: {score:_cons} + {score:age}*14 + {score:sex}*1) ///
                   (pred15: {score:_cons} + {score:age}*15 + {score:sex}*1) ///
                   (pred16: {score:_cons} + {score:age}*16 + {score:sex}*1) ///
                   (pred17: {score:_cons} + {score:age}*17 + {score:sex}*1) ///
                   (pred18: {score:_cons} + {score:age}*18 + {score:sex}*1)

return list
matlist r(summary)
				   
				   
bayesstats summary (pred14_m: {score:_cons} + {score:age}*14 + {score:sex}*1) ///
                   (pred15_m: {score:_cons} + {score:age}*15 + {score:sex}*1) ///
                   (pred16_m: {score:_cons} + {score:age}*16 + {score:sex}*1) ///
                   (pred17_m: {score:_cons} + {score:age}*17 + {score:sex}*1) ///
                   (pred18_m: {score:_cons} + {score:age}*18 + {score:sex}*1) ///
                   (pred14_f: {score:_cons} + {score:age}*14 + {score:sex}*0) ///
                   (pred15_f: {score:_cons} + {score:age}*15 + {score:sex}*0) ///
                   (pred16_f: {score:_cons} + {score:age}*16 + {score:sex}*0) ///
                   (pred17_f: {score:_cons} + {score:age}*17 + {score:sex}*0) ///
                   (pred18_f: {score:_cons} + {score:age}*18 + {score:sex}*0)

return list
matlist r(summary)
				   
				   
matrix pred = r(summary)
clear
svmat pred        /* Convert matrix to a dataset */
rename pred1 mean
rename pred2 stddev
rename pred3 mcse
rename pred4 median
rename pred5 lower
rename pred6 upper
gen sex = _n>5
label define sex 0 "Female" 1 "Male"
label values sex sex
gen age = _n + 13 if _n<6
replace age = _n + 8 if _n>5			   
	
#delimit ;	
twoway (rarea lower upper age if sex==0, fcolor(maroon%50) lcolor(maroon)) 
	   (rarea lower upper age if sex==1, fcolor(navy%50) lcolor(navy)) 
	   (line mean age if sex==0, lcolor(maroon)) 
	   (line mean age if sex==1, lcolor(navy))
	   , ytitle(Posterior Predicted Test Score) 
	   ylabel(, angle(horizontal)) 
	   xtitle(Age (years)) 
	   title(Predicted Test Score by Age) 
	   legend(on order(4 "Males" 3 "Females") position(12) ring(0))
;
#delimit cr
graph export ./graphs/bayes_predictions.png, as(png) width($Width16x9) height($Height16x9) replace



	
use test_1level, replace
	
regress score age sex
lincom _b[_cons] + _b[age]*16 + _b[sex]*1


regress score age i.sex
margins sex, at(age=(14(1)18)) vsquish
marginsplot, recast(line) recastci(rarea) ylabel(, angle(horizontal))
graph export ./graphs/linear_marginsplot.png, as(png) width($Width16x9) height($Height16x9) replace



quietly {
	bayes, rseed(15) saving(age, replace): regress score age
	estimates store age

	bayes, rseed(15) saving(sex, replace): regress score sex
	estimates store sex
	
	bayes, rseed(15) saving(full, replace): regress score age sex
	estimates store full
}

bayesstats ic age sex full, diconly
bayestest model age sex full
bayesstats ic age sex full, basemodel(full) bayesfactor







bayesmh score age sex,				    ///
	likelihood(normal({sigma2})) 	    ///
	prior({score:}, 	normal(0,100))	///
	prior({sigma2},     igamma(1,1))	


    
// Multiple Chains and Gelman-Rubin convergence diagnostics
// ======================================================== 
version 16   
bayes, nchains(5) rseed(15) : regress score age sex

bayesstats grubin _all

bayesstats ess

bayesgraph diagnostics {score:_cons}
graph export ./graphs/mc_cons.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph diagnostics {score:age}
graph export ./graphs/mc_age.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph diagnostics {score:sex}
graph export ./graphs/mc_sex.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph diagnostics {sigma2}
graph export ./graphs/mc_sigma2.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph trace {sigma2}
graph export ./graphs/mc_sigma2_trace.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph trace {score:_cons age sex} {sigma2}, byparm
graph export ./graphs/mc_trace.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph histogram {score:_cons age sex} {sigma2}, byparm
graph export ./graphs/mc_histogram.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph kdensity {score:_cons age sex} {sigma2}, byparm
graph export ./graphs/mc_kdensity.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph ac {score:_cons age sex} {sigma2}, byparm
graph export ./graphs/mc_ac.png, as(png) width($Width16x9) height($Height16x9) replace

bayesgraph matrix _all
graph export ./graphs/mc_matrix.png, as(png) width($Width16x9) height($Height16x9) replace					 
				 

log close


